package com.xyzc.start.controller;

import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.query.CollectDrawQuery;
import com.xyzc.start.domain.vo.*;
import com.xyzc.start.service.IMyCollectService;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 我的收藏
 *
 * @author 杨兴卓
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/myCollect")
@CrossOrigin
public class MyCollectController {

    private final IMyCollectService myCollectService;

    /**
     * 收藏的绘画模型
     */
    @GetMapping("/collectDraw")
    public Result<List<DrawModelCollectVo>> getCollectDrawModel(@Valid CollectDrawQuery query) {
        List<DrawModelCollectVo> drawModelList = myCollectService.getCollectDrawModel(query);

        return Result.ok(drawModelList);
    }

    /**
     * 收藏的图像
     */
    @GetMapping("/collectImage")
    public Result<List<DrawGraphicsCollectVo>> getCollectImage(Long collectId, String name) {
        List<DrawGraphicsCollectVo> drawGraphicsList = myCollectService.getCollectImage(collectId, name);

        return Result.ok(drawGraphicsList);
    }

    /**
     * 收藏的应用
     */
    @GetMapping("/collectApp")
    public Result<List<AppCollectVo>> getCollectApp(Long collectId, String name) {
        List<AppCollectVo> appList = myCollectService.getCollectApp(collectId, name);

        return Result.ok(appList);
    }

}
